! get_mm.f90
! Get a correct mean motion as an average from two semimajor axis values. (It will be stored as elmts_pl(7).)

FUNCTION Get_MM(a_0, a_1, t_0, t_1, M_0, M_1, planet, mass, nbod) 

implicit none
real*8 Get_MM
real*8 a_0, a_1, t_0, t_1, M_0, M_1
real*8 mass(nbod)
integer planet, nbod

real*8 zero2pi

real*8 aavg, n, n_corr, n_0, n_1, tmp
real*8 M_10, M_bet, A, B
real*8, parameter :: pi = 3.141592653589d0, deg = pi/180.d0, rad = 180.d0/pi

! use average semimajor axis between t_0 and t_1
aavg = (a_0 + a_1) / 2.d0
n = aavg**(-1.5d0) * sqrt((mass(1)+mass(planet)))
M_10 = n * (t_1 - t_0) + M_0

! correct mean motion in order to reach EXACTLY M_1 at time t_1
if (abs(M_1-zero2pi(M_10)).gt.pi) then
  M_1 = M_1 + 2.d0*pi
endif
n_corr = n + (M_1 - zero2pi(M_10)) / (t_1 - t_0)

n_0 = a_0**(-1.5d0) * sqrt(mass(1)+mass(planet))
n_1 = a_1**(-1.5d0) * sqrt(mass(1)+mass(planet))

if (n_0.gt.n_1) then
  tmp = n_0
  n_0 = n_1
  n_1 = tmp
endif

A = (a_1-a_0)/(t_1-t_0)
B = a_0 - A*t_0
M_bet = M_0 + sqrt(mass(1)+mass(planet)) * (-2.d0/A*(A*t_1+B)**(-0.5d0) + 2.d0/A*(A*t_0+B)**(-0.5))

if (planet.eq.2) then
  write (*,*)
  write(*,*) "t_0, t_1 = ", t_0/365.25d6, t_1/365.25d6, " Myr, dt = ", (t_1-t_0)/365.25d0, " yr"
  write(*,*) "M_0 = ", M_0*rad, " deg"
  write(*,*) "M_1 = ", M_1*rad, " deg"
  write(*,*) "M_10 = ", M_10*rad, " deg = ", zero2pi(M_10)*rad, " deg"
  write(*,*) "M_bet = ", M_bet*rad, " deg = ", zero2pi(M_bet)*rad, " deg"
  write(*,*) "n      = ", n
  write(*,*) "n_corr = ", n_corr
!  if (t_0.gt.0.01d0*365.25d6) stop

  write(*,*) n_0, n_corr, n_1

  if ((n_corr.lt.n_0).or.(n_corr.gt.n_1)) then
    write(*,*) 'ERROR!!!'
  endif
endif


Get_MM = n_corr

END FUNCTION


