! read_elements.f90
! Read elements from the input file (morby_follow.out), calculate also mean motion.

SUBROUTINE READ_ELEMENTS(filename, t_0, t_start, t_stop, mass, nbod) 

      implicit none
      include 'elements.inc'
      character*(*) filename
      integer nbod
      real*8 mass(nbod)
      real*8 t_0, t_start, t_stop

      real*8 a,e,inc,capom,omega,capm
      real*8 a_0, a_1, t0, t1, M_0, M_1 ! variables to compute mean motion
      integer planet
      real*8 t
      integer n, m
      real*8, parameter :: pi = 3.141592653589d0, rad = pi/180.d0
      real*8 Get_MM

      elmts_pl = 0.D0 
      WRITE(*,*)
      WRITE(*,*) 'READ_ELEMENTS: Entering READ_ELEMENTS subroutine with the following values:'
      WRITE(*,*) 'Filename = ', filename
      WRITE(*,*) 't_0 = ', t_0, ' day = ', t_0/365.25d6, ' Myr'
      WRITE(*,*) 't_start = ', t_start, ' day = ', t_start/365.25d6, ' Myr'
      WRITE(*,*) 't_stop = ', t_stop, ' day = ', t_stop/365.25d6, ' Myr'
      OPEN(1, FILE=filename)

      n = 0
      m = 0
      DO
          READ(1,*, err=990, end=990) planet, t, a, e, inc, capom, omega, capm 
          planet = ABS(planet)
          IF (planet.EQ.2) THEN
                times_pl(n+1) = t*365.25d6 - t_0
                n = n + 1
          ENDIF
          elmts_pl(n,planet,1) = a
          elmts_pl(n,planet,2) = e
          elmts_pl(n,planet,3) = inc * rad
          elmts_pl(n,planet,4) = capom * rad 
          elmts_pl(n,planet,5) = omega * rad
          elmts_pl(n,planet,6) = capm * rad

          IF (n.GT.1) THEN
            a_0 = elmts_pl(n-1,planet,1)
            a_1 = elmts_pl(n,planet,1)
            M_0 = elmts_pl(n-1,planet,6)
            M_1 = elmts_pl(n,planet,6)
            t0 = times_pl(n-1)
            t1 = times_pl(n)
            elmts_pl(n-1,planet,7) = Get_MM(a_0, a_1, t0, t1, M_0, M_1, planet, mass, nbod)
          ENDIF
          m = m + 1
      ENDDO
      
990 CONTINUE

    CLOSE(1)
    times_pl_n = n

! debugging and checks
    WRITE(*,*) 'READ_ELEMENTS:', m, 'lines was read from ', filename
    WRITE(*,*) 'READ_ELEMENTS: times_pl(1) = ', times_pl(1)
    WRITE(*,*) 'READ_ELEMENTS: times_pl(n) = ', times_pl(n)

    IF (t_stop.GT.times_pl(n).OR.t_stop.LT.times_pl(1)) THEN
        WRITE(*,*) 'READ_ELEMENTS: T_stop out of range'
        STOP
    ENDIF

    IF (t_start.GT.times_pl(n).OR.t_start.LT.times_pl(1)) THEN
        WRITE(*,*) 'READ_ELEMENTS: T_start out of range'
        STOP
    ENDIF

    WRITE(*,*) 'Exiting READ_ELEMENTS subroutine'
    RETURN

END SUBROUTINE
