c*************************************************************************
c                            STEP_KDK_PL.F
c*************************************************************************
c This subroutine takes a step in helio coord.  
c Does a KICK than a DRIFT than a KICK.
c ONLY DOES MASSIVE PARTICLES
c
c             Input:
c                 i1st          ==>  = 0 if first step; = 1 not (int scalar)
c                 nbod          ==>  number of massive bodies (int scalar)
c                 mass          ==>  mass of bodies (real array)
c                 j2rp2,j4rp4   ==>  J2*radii_pl^2 and  J4*radii_pl^4
c                                     (real scalars)
c                 xh,yh,zh      ==>  initial position in helio coord 
c                                    (real arrays)
c                 vxh,vyh,vzh   ==>  initial velocity in helio coord 
c                                    (real arrays)
c                 dt            ==>  time step
c             Output:
c                 xh,yh,zh      ==>  final position in helio coord 
c                                       (real arrays)
c                 vxh,vyh,vzh   ==>  final velocity in helio coord 
c                                       (real arrays)
c
c Remarks: Adopted from martin's nbwhnew.f program
c Authors:  Hal Levison 
c Date:    2/12/93
c Last revision: 2/24/94
c
c A MODIFIED VERSION with orbital elements of planets read from input file!

      subroutine step_kdk_pl(i1st,nbod,mass,j2rp2,j4rp4,
     &     xh,yh,zh,vxh,vyh,vzh,dt)	

      include '../../swift.inc'

c...  Inputs Only: 
      integer nbod,i1st
      real*8 mass(nbod),dt,j2rp2,j4rp4

c...  Inputs and Outputs:
      real*8 xh(nbod),yh(nbod),zh(nbod)
      real*8 vxh(nbod),vyh(nbod),vzh(nbod)

c...  Internals:
      real*8 dth 
      real*8 axh(NPLMAX),ayh(NPLMAX),azh(NPLMAX)
      real*8 xj(NPLMAX),yj(NPLMAX),zj(NPLMAX)
      real*8 vxj(NPLMAX),vyj(NPLMAX),vzj(NPLMAX)
      integer i, ialpha
      real*8 Elemets(7), a,e,inc,capom,omega,capm

      save axh,ayh,azh,xj,yj,zj     ! Note this !!
      real*8 deg
c----
c...  Executable code 
      real*8 t
      COMMON /times/ t

      dth = 0.5d0*dt
      
      ialpha = -1
      do i = 2,nbod

        call GetElements(t+dt, i, mass, nbod, a, e, inc, capom, 
     &  omega, capm)
        call orbel_el2xv(mass(1)+mass(i),ialpha, a,e,inc,capom,
     &  omega,capm, xh(i),yh(i),zh(i),vxh(i),vyh(i),vzh(i))
       
      enddo

      
c      if(i1st.eq.0) then
cc...      Convert to jacobi coords
c          call coord_h2j(nbod,mass,xh,yh,zh,vxh,vyh,vzh,
c     &          xj,yj,zj,vxj,vyj,vzj)
cc...     Get the accelerations in helio frame. if frist time step
c         call getacch(nbod,mass,j2rp2,j4rp4,xj,yj,zj,
c     &         xh,yh,zh,axh,ayh,azh)
c         i1st = 1    ! turn this off
c      endif

cc...  Apply a heliocentric kick for a half dt 
c      call kickvh(nbod,vxh,vyh,vzh,axh,ayh,azh,dth)

cc...  Convert the helio. vels. to Jac. vels. (the Jac. positions are unchanged)
c      call coord_vh2vj(nbod,mass,vxh,vyh,vzh,vxj,vyj,vzj)

cc..   Drift in Jacobi coords for the full step 
c      call drift(nbod,mass,xj,yj,zj,vxj,vyj,vzj,dt)

cc...  After drift, compute helio. xh and vh for acceleration calculations
c      call coord_j2h(nbod,mass,xj,yj,zj,vxj,vyj,vzj,
c     &             xh,yh,zh,vxh,vyh,vzh)

cc...  Get the accelerations in helio frame.
c      call getacch(nbod,mass,j2rp2,j4rp4,xj,yj,zj,xh,yh,zh,axh,ayh,azh)

cc...  Apply a heliocentric kick for a half dt 
c      call kickvh(nbod,vxh,vyh,vzh,axh,ayh,azh,dth)

      return
      end   ! step_kdk_pl
c---------------------------------------------------------------------

